@@ -8,8 +8,8 @@ class Seldom:
     Seldom browser driver
     """
     driver = None
-    timeout = None
-    debug = None
+    timeout = 10
+    debug = False
 
 
 class BrowserConfig:
@@ -18,13 +18,3 @@ class BrowserConfig:
     """
     name = None
     report_path = None
-
-
-class RunResult:
-    """
-    Test run results
-    """
-    passed = 0
-    failed = 0
-    errors = 0
-    skiped = 0
